@@ -96,7 +96,7 @@ class MultipleFormatResponseMixin(TemplateResponseMixin):
         if self.format is not None:
             return self.format
         
-        if self.request.is_ajax():
+        if self.request.is_ajax() and 'format' not in self.kwargs:
             self.format = 'json'
         else:
             self.format = self.kwargs.get('format', self.default_format)
@@ -272,7 +272,6 @@ class ActionResponseMixin(MultipleFormatResponseMixin):
         """
         Retorna el contexto de la acción
         """
-  
         self.success = success
         
         context.update({
@@ -281,6 +280,9 @@ class ActionResponseMixin(MultipleFormatResponseMixin):
             'redirect': self.redirect
         })
         
+        if self.get_format() == 'json' and 'request' in context:
+            del context['request']
+
         if self.redirect and self.request.method == 'POST':
             context['redirect_url'] = self.get_redirect_url(success)
         
@@ -340,7 +342,7 @@ class ActionResponseMixin(MultipleFormatResponseMixin):
         """
         Retorna la respuesta de la acción.
         """
-
+        
         self.success = success
         
         if message is not None:
@@ -394,7 +396,7 @@ class LoginRequiredMixin(ActionResponseMixin):
         Despacha al metodo adecuado verificando si el usuario esta identificado,
         si no, redirecciona a la página de login.
         """
-
+        
         self.request = request
         self.args = args
         self.kwargs = kwargs
@@ -631,8 +633,10 @@ class ActionView(ActionResponseMixin, TemplateView):
         
         context.update({
             'confirm_message': unicode(self.confirm_message),
-            'confirm': True
+            'confirm': True,
         })
+        if self.get_format() != 'json':
+            context['request'] = self.request
 
         return super(ActionView, self).get_context_data(success=success, **context)
 
